@@ -13,7 +13,7 @@ my $arg = join('',@ARGV);
 $mali = 1 if ($arg =~ /mali/i); # Mali GPU correction mode
 $file = 1 if ($arg =~ /file/i); # File Handle drawing mode
 
-my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0','FILE_MODE' => $file,'SHOW_ERRORS' => 0,'LINE_PADDING'=> 0);
+my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0','FILE_MODE' => $file,'SHOW_ERRORS' => 1,'LINE_PADDING'=> 0);
 
 $SIG{'QUIT'} = sub { $F->cls('ON'); exit(0); };
 $SIG{'INT'}  = sub { $F->cls('ON'); exit(0); };
@@ -374,6 +374,18 @@ foreach my $re (1..(5 * $factor)) {
 
 sleep $wait;
 
+print_it($F,'Image load');
+
+$F->blit_write($F->load_image(
+    {
+        'x' => 0,
+        'y' => 0,
+        'file' => 'RWBY_Faces.png',
+    }
+));
+
+sleep $wait;
+
 $F->cls('ON');
 
 exit(0);
